@@ -128,7 +128,7 @@ void GraphicsScene::mousePressEvent(QGraphicsSceneMouseEvent* event)
 			
 			animOp = new QPropertyAnimation(m_grid[element], "opacity");
 			animOp->setStartValue(0);
-			animOp->setDuration(500);
+			animOp->setDuration(400);
 			animOp->setEndValue(1);
 			animOp->start();	
 			m_grid[element]->addData(Shapes,Human);
@@ -173,7 +173,7 @@ void GraphicsScene::CPUMove()
 	
 	animOp = new QPropertyAnimation(m_grid[element], "opacity");
 	animOp->setStartValue(0);
-	animOp->setDuration(1000);
+	animOp->setDuration(800);
 	animOp->setEndValue(1);
 	animOp->start();	
 
@@ -310,16 +310,14 @@ bool GraphicsScene::checkFinish()
 void GraphicsScene::endFinalLine()
 {
 	if (ganador == Machine) {
-		m_winner->setPlainText("Machine has won!");
-		m_winner->setPos(-75, -150);
+		m_winner->setPlainText("You have lost!");
+		m_winner->setPos(-50, -150);
 	}
-	if (ganador == Human ) // && userName.isEmpty())
+	if (ganador == Human )
 	{
-		m_winner->setPlainText("You has won!");
+		m_winner->setPlainText("You have won!");
 		m_winner->setPos(-55, -150);
 	}
-// 	if (ganador == Human && !userName.isEmpty())
-// 		m_winner->setPlainText(userName + " has won!");
 	if (ganador == Human+Machine) {
 		m_winner->setPlainText("Tie Game!");
 		m_winner->setPos(-35, -150);
