@@ -28,15 +28,44 @@ GraphicsView::GraphicsView(QWidget* parent): QGraphicsView(parent)
 	setCacheMode(CacheBackground);
 	setRenderHint(QPainter::Antialiasing);
 
-	GraphicsScene* scene = new GraphicsScene(this);
+	scene = new GraphicsScene(this);
 	setScene(scene);
-	
 	setSceneRect(-350, -170, 800, 420);
 	setBackgroundBrush(Qt::black);
 }
 
+GraphicsView::~GraphicsView()
+{
+	delete scene;
+}
+
 void GraphicsView::showEvent(QShowEvent* event)
 {
-// 	QGraphicsView::showEvent(event);
+	QGraphicsView::showEvent(event);
 	centerOn(100,100);
 }
+
+void GraphicsView::changeLevel()
+{
+	scene->changeLevel();
+}
+
+void GraphicsView::restartGame()
+{
+	scene->restartGame();
+}
+
+// void GraphicsView::askUserName()
+// {
+// 	scene->askUserName();
+// }
+
+void GraphicsView::statistics()
+{
+	scene->statistics();
+}
+
+void GraphicsView::changeShape()
+{
+	scene->changeShape();
+}
